# eric7.Plugins.VcsPlugins.vcsGit.GitBundleDialog

Module implementing a dialog to enter the data for a bundle operation.

### Global Attributes

None

### Classes

GitBundleDialog | Class implementing a dialog to enter the data for a bundle operation.

### Functions

None

## GitBundleDialog

Class implementing a dialog to enter the data for a bundle operation.

### Derived from

QDialog, Ui_GitBundleDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitBundleDialog | Constructor
__updateOK | Private slot to update the OK button.
getData | Public method to retrieve the bundle data.
on_branchButton_toggled | Private slot to handle changes of the Branch select button.
on_branchCombo_editTextChanged | Private slot to handle changes of the Branch combo.
on_revisionsButton_toggled | Private slot to handle changes of the revisions select button.
on_revisionsEdit_textChanged | Private slot to handle changes of the Revisions edit.
on_tagButton_toggled | Private slot to handle changes of the Tag select button.
on_tagCombo_editTextChanged | Private slot to handle changes of the Tag combo.

### Static Methods

None

#### GitBundleDialog (Constructor)

GitBundleDialog(tagsList, branchesList, parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
parent (QWidget)
  parent widget

#### GitBundleDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### GitBundleDialog.getData

getData()

Public method to retrieve the bundle data.

Return:
  list of revision expressions

Return Type:
  list of str

#### GitBundleDialog.on_branchButton_toggled

on_branchButton_toggled(_checked)

Private slot to handle changes of the Branch select button.

_checked (bool)
  state of the button (unused)

#### GitBundleDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(_txt)

Private slot to handle changes of the Branch combo.

_txt (str)
  text of the combo (unused)

#### GitBundleDialog.on_revisionsButton_toggled

on_revisionsButton_toggled(_checked)

Private slot to handle changes of the revisions select button.

_checked (bool)
  state of the button (unused)

#### GitBundleDialog.on_revisionsEdit_textChanged

on_revisionsEdit_textChanged(_txt)

Private slot to handle changes of the Revisions edit.

_txt (str)
  text of the line edit (unused)

#### GitBundleDialog.on_tagButton_toggled

on_tagButton_toggled(_checked)

Private slot to handle changes of the Tag select button.

_checked (bool)
  state of the button (unused)

#### GitBundleDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(_txt)

Private slot to handle changes of the Tag combo.

_txt (str)
  text of the combo (unused)

Up